==> kubernetes-model-core-6.6.2-sources.jar: io/fabric8/kubernetes/api/model/ClaimSourceFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ClaimSourceFluentImpl<A extends ClaimSourceFluent<A>> extends BaseFluent<A> implements ClaimSourceFluent<A>{
  public ClaimSourceFluentImpl() {
  }
  public ClaimSourceFluentImpl(ClaimSource instance) {
    this.withResourceClaimName(instance.getResourceClaimName()); 
    this.withResourceClaimTemplateName(instance.getResourceClaimTemplateName()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private String resourceClaimName;
  private String resourceClaimTemplateName;
  private Map<String,Object> additionalProperties;
  public String getResourceClaimName() {
    return this.resourceClaimName;
  }
  public A withResourceClaimName(String resourceClaimName) {
    this.resourceClaimName=resourceClaimName; return (A) this;
  }
  public Boolean hasResourceClaimName() {
    return this.resourceClaimName != null;
  }
  public String getResourceClaimTemplateName() {
    return this.resourceClaimTemplateName;
  }
  public A withResourceClaimTemplateName(String resourceClaimTemplateName) {
    this.resourceClaimTemplateName=resourceClaimTemplateName; return (A) this;
  }
  public Boolean hasResourceClaimTemplateName() {
    return this.resourceClaimTemplateName != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ClaimSourceFluentImpl that = (ClaimSourceFluentImpl) o;
    if (resourceClaimName != null ? !resourceClaimName.equals(that.resourceClaimName) :that.resourceClaimName != null) return false;
    if (resourceClaimTemplateName != null ? !resourceClaimTemplateName.equals(that.resourceClaimTemplateName) :that.resourceClaimTemplateName != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(resourceClaimName,  resourceClaimTemplateName,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (resourceClaimName != null) { sb.append("resourceClaimName:"); sb.append(resourceClaimName + ","); }
    if (resourceClaimTemplateName != null) { sb.append("resourceClaimTemplateName:"); sb.append(resourceClaimTemplateName + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> kubernetes-model-core-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/ClaimSourceFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ClaimSourceFluentImpl<A extends ClaimSourceFluent<A>> extends BaseFluent<A> implements ClaimSourceFluent<A>{
  public ClaimSourceFluentImpl() {
  }
  public ClaimSourceFluentImpl(ClaimSource instance) {
    if (instance != null) {
      this.withResourceClaimName(instance.getResourceClaimName());
      this.withResourceClaimTemplateName(instance.getResourceClaimTemplateName());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private String resourceClaimName;
  private String resourceClaimTemplateName;
  private Map<String,Object> additionalProperties;
  public String getResourceClaimName() {
    return this.resourceClaimName;
  }
  public A withResourceClaimName(String resourceClaimName) {
    this.resourceClaimName=resourceClaimName; return (A) this;
  }
  public Boolean hasResourceClaimName() {
    return this.resourceClaimName != null;
  }
  public String getResourceClaimTemplateName() {
    return this.resourceClaimTemplateName;
  }
  public A withResourceClaimTemplateName(String resourceClaimTemplateName) {
    this.resourceClaimTemplateName=resourceClaimTemplateName; return (A) this;
  }
  public Boolean hasResourceClaimTemplateName() {
    return this.resourceClaimTemplateName != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ClaimSourceFluentImpl that = (ClaimSourceFluentImpl) o;
    if (!java.util.Objects.equals(resourceClaimName, that.resourceClaimName)) return false;

    if (!java.util.Objects.equals(resourceClaimTemplateName, that.resourceClaimTemplateName)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(resourceClaimName,  resourceClaimTemplateName,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (resourceClaimName != null) { sb.append("resourceClaimName:"); sb.append(resourceClaimName + ","); }
    if (resourceClaimTemplateName != null) { sb.append("resourceClaimTemplateName:"); sb.append(resourceClaimTemplateName + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
}
